# Generated by Django 3.2.13 on 2022-09-07 02:49

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('org_model_logs', '0008_rename_type_entrytype_entry_type'),
    ]

    operations = [
        migrations.AlterField(
            model_name='communicationslogentry',
            name='customer',
            field=models.IntegerField(null=True),
        ),
    ]
