# Generated by Django 3.2.13 on 2022-09-07 00:59

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('org_model_logs', '0007_alter_entrytype_options'),
    ]

    operations = [
        migrations.RenameField(
            model_name='entrytype',
            old_name='type',
            new_name='entry_type',
        ),
    ]
