# Generated by Django 3.2.13 on 2022-06-21 08:14

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('contenttypes', '0002_remove_content_type_name'),
    ]

    operations = [
        migrations.CreateModel(
            name='UserAction',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('object_id', models.CharField(help_text='Primary key of the model.', max_length=191)),
                ('who', models.IntegerField()),
                ('when', models.DateTimeField(auto_now_add=True)),
                ('what', models.TextField()),
                ('content_type', models.ForeignKey(help_text='Content type of the model.', on_delete=django.db.models.deletion.CASCADE, to='contenttypes.contenttype')),
            ],
        ),
        migrations.CreateModel(
            name='CommunicationsLogEntry',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('object_id', models.CharField(help_text='Primary key of the model.', max_length=191)),
                ('to', models.TextField(blank=True, verbose_name='To')),
                ('fromm', models.CharField(blank=True, max_length=200, verbose_name='From')),
                ('cc', models.TextField(blank=True, verbose_name='cc')),
                ('type', models.CharField(choices=[('email', 'Email'), ('phone', 'Phone Call'), ('mail', 'Mail'), ('person', 'In Person'), ('onhold', 'On Hold'), ('onhold_remove', 'Remove On Hold'), ('with_qaofficer', 'With QA Officer'), ('with_qaofficer_completed', 'QA Officer Completed'), ('referral_complete', 'Referral Completed')], default='email', max_length=35)),
                ('reference', models.CharField(blank=True, max_length=100)),
                ('subject', models.CharField(blank=True, max_length=200, verbose_name='Subject / Description')),
                ('text', models.TextField(blank=True)),
                ('customer', models.IntegerField()),
                ('staff', models.IntegerField()),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('content_type', models.ForeignKey(help_text='Content type of the model.', on_delete=django.db.models.deletion.CASCADE, to='contenttypes.contenttype')),
            ],
        ),
        migrations.AddIndex(
            model_name='useraction',
            index=models.Index(fields=['content_type', 'object_id'], name='org_model_l_content_a3d2eb_idx'),
        ),
        migrations.AlterUniqueTogether(
            name='useraction',
            unique_together={('content_type', 'object_id')},
        ),
        migrations.AddIndex(
            model_name='communicationslogentry',
            index=models.Index(fields=['content_type', 'object_id'], name='org_model_l_content_4eadf2_idx'),
        ),
        migrations.AlterUniqueTogether(
            name='communicationslogentry',
            unique_together={('content_type', 'object_id')},
        ),
    ]
