from django.apps import AppConfig


class OrgModelLogsConfig(AppConfig):
    default_auto_field = "django.db.models.BigAutoField"
    name = "org_model_logs"
    verbose_name = "Park Pass Model Logs"
