# Generated by Django 3.2.13 on 2022-08-12 05:53

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('org_model_logs', '0004_alter_communicationslogentry_unique_together'),
    ]

    operations = [
        migrations.AddField(
            model_name='useraction',
            name='why',
            field=models.TextField(blank=True, null=True),
        ),
    ]
