# Generated by Django 3.2.13 on 2022-09-02 05:57

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('org_model_logs', '0005_useraction_why'),
    ]

    operations = [
        migrations.CreateModel(
            name='EntryType',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('type', models.CharField(max_length=100)),
            ],
            options={
                'verbose_name': 'Entry Type',
                'verbose_name_plural': 'Entry Types',
            },
        ),
        migrations.RemoveField(
            model_name='communicationslogentry',
            name='type',
        ),
        migrations.AddField(
            model_name='communicationslogentry',
            name='entry_type',
            field=models.ForeignKey(default=None, on_delete=django.db.models.deletion.PROTECT, to='org_model_logs.entrytype'),
        ),
    ]
