# Generated by Django 3.2.13 on 2022-08-04 06:47

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('org_model_logs', '0002_alter_communicationslogentry_options'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='useraction',
            unique_together=set(),
        ),
    ]
