# Generated by Django 3.2.13 on 2022-06-23 02:12

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('org_model_logs', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='communicationslogentry',
            options={'verbose_name': 'Communications Log Entry', 'verbose_name_plural': 'Communications Log Entries'},
        ),
    ]
